@@ -2,42 +2,32 @@ use crate::model::request_record::RequestRecord;
 use crate::worker::worker::Worker;
 use chrono::Utc;
 use crossbeam::channel::{Receiver, Sender};
-use reqwest::blocking::Client;
-use reqwest::Url;
-use std::str::FromStr;
-use crate::model::http_config::HttpRequestConfig;
+use reqwest::blocking::{Client, Request};
 
 pub struct HttpWorker {
     work_recv: Receiver<bool>,
     output_send: Sender<Option<RequestRecord>>,
     feedback_send: Sender<bool>,
-    http_config: HttpRequestConfig,
+    request: Request,
 }
 
-impl Worker<HttpRequestConfig, RequestRecord> for HttpWorker {
+impl Worker<Request, RequestRecord> for HttpWorker {
     fn new(
         work_recv: Receiver<bool>,
         output_send: Sender<Option<RequestRecord>>,
         feedback_send: Sender<bool>,
-        http_config: HttpRequestConfig,
+        request: Request,
     ) -> HttpWorker {
         HttpWorker {
             work_recv,
             output_send,
             feedback_send,
-            http_config,
+            request,
         }
     }
 
     fn start(&self) {
         let c = Client::new();
-        let url = Url::from_str(self.http_config.url.as_str()).expect("Could not parse Url");
-        let r = c
-            .request(self.http_config.get_method(), url)
-            .body(self.http_config.body.clone())
-            .headers(self.http_config.get_header_map())
-            .build()
-            .expect("Could not create request");
 
         while self
             .work_recv
@@ -46,7 +36,7 @@ impl Worker<HttpRequestConfig, RequestRecord> for HttpWorker {
         {
             let start = Utc::now();
             let b = c
-                .execute(r.try_clone().expect("Could not clone request"))
+                .execute(self.request.try_clone().expect("Could not clone request"))
                 .expect("Http Request failure");
             let latency = Utc::now() - start;
             let rr = RequestRecord::new(latency, b.status().as_u16(), b.text().unwrap());
